#include "GeneralIonChannelDataReadIn.hpp"
#include <iostream>
#include <fstream>
#include <sstream>
#include <string>
#include <cassert>
#include "UblasVectorInclude.hpp"

#include "GeneralIonChannelDataReadIn.hpp"
#include "Exception.hpp"

GeneralIonChannelDataReadIn::GeneralIonChannelDataReadIn(std::string file, unsigned number_of_channels)
   :mNumberOfChannels(number_of_channels)
{
	LoadDataFromFile(file);
}

void GeneralIonChannelDataReadIn::LoadDataFromFile(std::string file)
{
	std::ifstream input;
	input.open(file.c_str());
	if(!input.good())
	{
		EXCEPTION("Couldn't open data file: " + file);
	}

	while (input.good())
	{
		std::string this_line;
		getline(input, this_line);

		std::stringstream line(this_line);

		LoadALine(line);
	}

}

unsigned GeneralIonChannelDataReadIn::GetNumberOfDrugs(void)
{
	return mDrugNames.size();
}

std::string GeneralIonChannelDataReadIn::GetDrugName(unsigned drugIndex)
{
	assert(drugIndex < GetNumberOfDrugs());
	return mDrugNames[drugIndex];
}

double GeneralIonChannelDataReadIn::GetFreq(unsigned drugIndex)
{
	return mFreq[drugIndex];
}

double GeneralIonChannelDataReadIn::GetIC50Value(unsigned drugIndex, unsigned channelIndex)
{
	assert(drugIndex < GetNumberOfDrugs());

	double IC50 = mIC50values[drugIndex][channelIndex];

	return IC50;
}

double GeneralIonChannelDataReadIn::GetHillCoefficient(unsigned drugIndex, unsigned channelIndex)
{
	assert(drugIndex < GetNumberOfDrugs());

	double hill = mHillCoefficients[drugIndex][channelIndex];

	return hill;
}

