#ifndef GENERALIONCHANNELDATAREADIN_HPP_
#define GENERALIONCHANNELDATAREADIN_HPP_

#include <vector>
#include <sstream>
#include <fstream>
#include <iostream>
#include <string>
#include <cassert>
#include "UblasVectorInclude.hpp"
class GeneralIonChannelDataReadIn
{
private:
	unsigned mNumberOfChannels;

protected:

	virtual void LoadALine(std::stringstream& rLine)
	{
		std::string name;
		std::vector<double> ic50s;
		ic50s.resize(mNumberOfChannels);
		std::vector<double> hills;
		hills.resize(mNumberOfChannels);
		std::vector<double> doses;
		double freq;

		//Data entries for each compound read in sequentially
		rLine >> name;
		rLine >> freq;
		// IKr channel data
		rLine >> ic50s[0];
		rLine >> hills[0];
		// INa channel data
		rLine >> ic50s[1];
		rLine >> hills[1];
		// ICaL channel data
		rLine >> ic50s[2];
		rLine >> hills[2];
		if (mNumberOfChannels==4)
		{
			rLine >> ic50s[3];
			rLine >> hills[3];
		}

		unsigned number_doses;
		rLine >> number_doses;
		doses.resize(number_doses);
		double temp;
		for (unsigned i=0; i<number_doses; ++i)
		{
			rLine >> temp;
			doses[i] = temp;
		}

		this->mDrugNames.push_back(name);
		this->mFreq.push_back(freq);
		this->mIC50values.push_back(ic50s);
		this->mHillCoefficients.push_back(hills);
		mDoses.push_back(doses);
	};

	std::vector<std::vector<double> > mDoses;
    std::vector<std::string> mDrugNames;
    std::vector<double> mFreq;
    std::vector<std::vector<double> > mIC50values;
    std::vector<std::vector<double> > mHillCoefficients;

public:

   GeneralIonChannelDataReadIn(std::string file, unsigned number_of_channels);

   void LoadDataFromFile(std::string file);



public:

   GeneralIonChannelDataReadIn(){};

   virtual ~GeneralIonChannelDataReadIn(){};

   unsigned GetNumberOfDrugs(void);

   std::string GetDrugName(unsigned drugIndex);

   double GetFreq(unsigned drugIndex);

   std::vector<double> GetDoses(unsigned drugIndex)
   {
	   assert(drugIndex < GetNumberOfDrugs());
	   return mDoses[drugIndex];
   }

   double GetIC50Value(unsigned drugIndex, unsigned channelIndex);

   double GetHillCoefficient(unsigned drugIndex, unsigned channelIndex);




};

#endif // GENERALIONCHANNELDATAREADIN_HPP_
