#include <vector>
#include <cmath>
#include "Exception.hpp"
#include "RegularStimulus.hpp"
#include "AbstractIvpOdeSolver.hpp"
#include "shannon_wang_puglisi_weber_bers_2004Cvode.hpp"
#include "AbstractCvodeCell.hpp"
#include "AbstractCardiacCell.hpp"
#include "OdeSolution.hpp"
#include "RegularStimulus.hpp"
#include "OdeSystemInformation.hpp"
#include "VectorHelperFunctions.hpp"
#include <boost/shared_ptr.hpp>
#include "SteadyState.hpp"

SteadyState::SteadyState(boost::shared_ptr<AbstractCvodeCell> pModel)
:mpModel(pModel),
 mNumberOfPaces(0u)
{}

//Implementation of method to detect when steady state reached
void SteadyState::RunToSteadyState()
{
	boost::shared_ptr<RegularStimulus> p_stimulus = boost::static_pointer_cast<RegularStimulus>(mpModel->GetStimulusFunction());

	double stim_period = p_stimulus->GetPeriod(); //ms

	double maximum_time_step = 1;

	std::vector<double> state_vars;
	std::vector<double> state_vars_after_solve;

	CopyToStdVector(mpModel->rGetStateVariables(),state_vars);

	for (unsigned pace_number=0; pace_number<2500; pace_number++)
	{

		mpModel->Solve((stim_period)*(double)(pace_number), (stim_period)*(double)(pace_number+1), maximum_time_step);
		this->mNumberOfPaces += 1;
		CopyToStdVector(mpModel->rGetStateVariables(),state_vars_after_solve);

		// Calculate the change in square difference of state variables
		double squaresum = 0;
		for(unsigned var_num = 0; var_num<state_vars.size();var_num++)
		{
			squaresum = squaresum + pow(fabs(state_vars_after_solve[var_num]-state_vars[var_num]),2);

		}

		if (sqrt(squaresum) < 1e-6)
		{
		break;
		}

		state_vars = state_vars_after_solve;
	}

	mpModel->SetAutoReset(true);

}

// Returns number of paces needs for steady state to be reached
unsigned SteadyState::GetNumberOfPaces()
{
	return mNumberOfPaces;
}

