function calculating1dmetricvalues()
%Input name of results file here as %file = 'name'

file = 'PatchXpress_1D_1_Parameter_Multiple';
%file = 'PatchXpress_1D_2_Parameter_Multiple';

%Checks which assay the results are for
PX = strfind(file,'PatchXpress');
IW = strfind(file,'IonWorks');
QS = strfind(file,'QSAR');

% Extract names of componuds for which data are available for each assay as
% well as number of doses each compound is simulated for
if PX ==1
    fid = fopen('PatchXpress_Data_Matrix.dat');
    Namedata = textscan(fid, '%f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f', '\t');
    fclose(fid);
    Names = Namedata{1};
    SimDoseNumber = Namedata{9};
    NamesMatrix = Names;
end
if IW ==1
    fid = fopen('IonWorks_Data_Matrix.dat');
    Namedata = textscan(fid, '%f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f', '\t');
    fclose(fid);
    Names = Namedata{1};
    SimDoseNumber = Namedata{9};
    NamesMatrix = Names;
end
if QS ==1
    fid = fopen('QSAR_Data_Matrix.dat');
    Namedata = textscan(fid, '%f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f', '\t');
    fclose(fid);
    Names = Namedata{1};
    SimDoseNumber = Namedata{9};
    NamesMatrix = Names;
end

% Reads in rabbit wedge data file to extract concentrations tested and
% percent change in QT interval measured at each concentration
fid = fopen('Rabbit_Wedge_Data.dat');
RabbitWedgeData = textscan(fid, '%f %f %f %f','headerlines',1);
fclose(fid);

WedgeNames = RabbitWedgeData{1};
RabbitWedgeDataMatrix{1} = RabbitWedgeData{2};
RabbitWedgeDataMatrix{2} = RabbitWedgeData{3};
RabbitWedgeDataMatrix{3} = RabbitWedgeData{4};
RabbitWedgeMatrix = cell2mat(RabbitWedgeDataMatrix);

Concs = RabbitWedgeMatrix(:,1);
PercentChange = RabbitWedgeMatrix(:,3);

m = 1;
% Determines number of doses tested in rabbit wedge experiments for each
% compound
for i = 1:length(NamesMatrix)
    d = 1;
    
    for j = 1:length(WedgeNames)
        
        if strmatch(NamesMatrix(i),WedgeNames(j))
            
            DataDoseExtract(m,d) = Concs(j);
            QTDataExtract(m,d) = PercentChange(j);
            d = d+1;
            
        end
    end
    DoseNumber(m) = d-1;
    m = m+1;
end

%Changes to the input results folder
cd(file);

%Reads in information for all the folders for which there are simulation data
for o = 1:length(dir)
    dirData = dir;
end

%Constructs matrix of experimentally recorded QT percent change in the
%rabbit wedge experiments for each compound
for t = 1:length(Names)
    
    expmatrix(1:DoseNumber(t),t) =  QTDataExtract(t,1:DoseNumber(t));
end

% Moves in turn to each folder in the results folder to extract results
% needed for each compound in order to perform the evaluation
for t  = 1:length(Names)
    N = num2str(Names(t));
    C = 'Compound_';
    Name=strcat(C,N);
    for h = 1:length(dir)
        foldername =dirData(h).name;
        Name;
        if strcmp(Name,foldername)==1
            
            cd(foldername);
            Results_File = strcat('QT_Results.dat');
            
            fid = fopen(Results_File);
            M = textscan(fid,'%f %f %f');
            % Extracts simulation results from the results folder for each
            % compound
            
            %Corrected number of doses simulated for compounds where there is failed
            %propagation at higher concentrations
            
            if Names(t)==1620
                SimDoseNumber(t) =7;
            end
            if Names(t)==663
                SimDoseNumber(t) =7;
            end
            simmatrix(1:SimDoseNumber(t),t) = M{3};
            fclose(fid);
            cd ..
        end
    end
end



T = 10; % Threshold for prolongation >T% and for shortening (<-T%) set
%Initialises separate contingency matrices for evaluating prediction of
%prolongation and shortening
classification_matrix_prolongation = zeros(2);
classification_matrix_shortening = zeros(2);

for d = 1:length(Names)
    N =     length(Names);
    % vectors of simulation and expxerimental results for each compound
    sim_APD90Change_p(:,1) = simmatrix(:,d);
    exp_APD90Change_p(:,1) = expmatrix(:,d);
    sim_APD90Change_s(:,1) = simmatrix(:,d);
    exp_APD90Change_s(:,1) = expmatrix(:,d);
    threshold_p = T; % Threshold for prolongation
    threshold_s = -T; % Threshold for shortening
    sim_type_p = zeros(length(sim_APD90Change_p),1);
    sim_type_s = zeros(length(sim_APD90Change_s),1);
    %Classifying simulation result for prolongation
    % - sim_type_p = 1 => prolonger
    % - sim_type_p = 0 => non-prolonger
    for i = 1:length(sim_APD90Change_p)
        
        if sim_APD90Change_p(i,1) > threshold_p;
            sim_type_p(i,1) = sim_type_p(i,1)+1;
            
        end
    end
    % Classifying simulation results for shortening
    % - sim_type_s = 1 => shortener
    % - sim_type_s = 0 => non-shortener
    for i = 1:length(sim_APD90Change_s)
        
        if sim_APD90Change_s(i,1) < threshold_s;
            sim_type_s(i,1) = sim_type_s(i,1)+1;
            
        end
    end
    
    %Classifying experimental results for prolongation and shortening in the
    %same way
    % exp_type_p = 1 => prolonger
    % exp_type_p = 0 => non-prolonger
    % exp_type_s = 1 => shortener
    % exp_type_s = 0 => non-shortener
    exp_type_p = zeros(length(exp_APD90Change_p),1);
    exp_type_s = zeros(length(exp_APD90Change_s),1);
    
    for i = 1:length(exp_APD90Change_p)
        
        if exp_APD90Change_p(i,1)>threshold_p
            exp_type_p(i,1) = exp_type_p(i,1)+1;
            
        end
    end
    for i = 1:length(exp_APD90Change_s)
        
        if exp_APD90Change_s(i,1)<threshold_s
            exp_type_s(i,1) = exp_type_s(i,1)+1;
            
        end
    end
    %Classifying compound accordig to simulation and experimental data
    [r c] = (find(sim_type_p,1,'first'));
    if r>=1
        compound_class_sim_p = sim_type_p(r,c);
    else
        compound_class_sim_p = 0;
    end
    
    
    [r c] = (find(exp_type_p,1,'first'));
    if r>=1
        compound_class_exp_p = exp_type_p(r,c);
    else
        compound_class_exp_p = 0;
    end
    
    %Classifying compound accordig to simulation and experimental data
    [r c] = (find(sim_type_s,1,'first'));
    if r>=1
        compound_class_sim_s = sim_type_s(r,c);
    else
        compound_class_sim_s = 0;
    end
    
    
    [r c] = (find(exp_type_s,1,'first'));
    if r>=1
        compound_class_exp_s = exp_type_s(r,c);
    else
        compound_class_exp_s = 0;
    end
    
    %Creating and inputing compounds into classification matrix
    % matrix for prolongation of the form
    %               simulation prolonger       simulation non-prolonger
    % experimental
    % prolonger
    %
    % experimental
    % non-prolonger
    
    if(compound_class_sim_p ==1&&compound_class_exp_p==1)
        classification_matrix_prolongation(1,1) = classification_matrix_prolongation(1,1) + 1;
        
    end
    if(compound_class_sim_p ==0&&compound_class_exp_p==1)
        classification_matrix_prolongation(1,2) = classification_matrix_prolongation(1,2) + 1;
    end
    if(compound_class_sim_p ==1&&compound_class_exp_p==0)
        classification_matrix_prolongation(2,1) = classification_matrix_prolongation(2,1) + 1;
    end
    if(compound_class_sim_p ==0&&compound_class_exp_p==0)
        classification_matrix_prolongation(2,2) = classification_matrix_prolongation(2,2) + 1;
    end
    
    %Creating and inputing compounds into classification matrix
    % matrix for shortening of the form
    %               simulation shortener       simulation non-shortener
    % experimental
    % shortener
    %
    % experimental
    % non-shortener
    
    if(compound_class_sim_s ==1&&compound_class_exp_s==1)
        classification_matrix_shortening(1,1) = classification_matrix_shortening(1,1) + 1;
    end
    if(compound_class_sim_s ==0&&compound_class_exp_s==1)
        classification_matrix_shortening(1,2) = classification_matrix_shortening(1,2) + 1;
    end
    if(compound_class_sim_s ==1&&compound_class_exp_s==0)
        classification_matrix_shortening(2,1) = classification_matrix_shortening(2,1) + 1;
    end
    if(compound_class_sim_s ==0&&compound_class_exp_s==0)
        classification_matrix_shortening(2,2) = classification_matrix_shortening(2,2) + 1;
    end
end
format long
% Outputs classification matrices for prolongation and shortening
classification_matrix_prolongation
classification_matrix_shortening
%Calculates performance metrics and associated confidence intervals for
%each metric for both prolongation and shortening

%Kappa value
kappa_for_prolongation =  ((((classification_matrix_prolongation(1,1))/N)+((classification_matrix_prolongation(2,2))/N))-((((classification_matrix_prolongation(1,1)+classification_matrix_prolongation(1,2))/N)*((classification_matrix_prolongation(1,1)+classification_matrix_prolongation(2,1))/N))+((((classification_matrix_prolongation(2,1)+classification_matrix_prolongation(2,2))/N)*((classification_matrix_prolongation(1,2)+classification_matrix_prolongation(2,2))/N)))))/(1-((((classification_matrix_prolongation(1,1)+classification_matrix_prolongation(1,2))/N)*((classification_matrix_prolongation(1,1)+classification_matrix_prolongation(2,1))/N))+((((classification_matrix_prolongation(2,1)+classification_matrix_prolongation(2,2))/N)*((classification_matrix_prolongation(1,2)+classification_matrix_prolongation(2,2))/N)))))
p = (classification_matrix_prolongation(1,1)+classification_matrix_prolongation(2,2))/N;
p_e = ((1/(N*N))*((classification_matrix_prolongation(1,1)+classification_matrix_prolongation(1,2))*(classification_matrix_prolongation(1,1)+classification_matrix_prolongation(2,1))))+((1/(N*N))*((classification_matrix_prolongation(2,1)+classification_matrix_prolongation(2,2))*(classification_matrix_prolongation(1,2)+classification_matrix_prolongation(2,2))));
se_kappa_pro = sqrt((p*(1-p))/(N*((1-p_e)*(1-p_e))));
upper_confidence_on_kappa_for_prolongation = kappa_for_prolongation+1.96*se_kappa_pro
lower_confidence_on_kappa_for_prolongation = kappa_for_prolongation-1.96*se_kappa_pro
kappa_for_shortening =  ((((classification_matrix_shortening(1,1))/N)+((classification_matrix_shortening(2,2))/N))-((((classification_matrix_shortening(1,1)+classification_matrix_shortening(1,2))/N)*((classification_matrix_shortening(1,1)+classification_matrix_shortening(2,1))/N))+((((classification_matrix_shortening(2,1)+classification_matrix_shortening(2,2))/N)*((classification_matrix_shortening(1,2)+classification_matrix_shortening(2,2))/N)))))/(1-((((classification_matrix_shortening(1,1)+classification_matrix_shortening(1,2))/N)*((classification_matrix_shortening(1,1)+classification_matrix_shortening(2,1))/N))+((((classification_matrix_shortening(2,1)+classification_matrix_shortening(2,2))/N)*((classification_matrix_shortening(1,2)+classification_matrix_shortening(2,2))/N)))))
p = (classification_matrix_shortening(1,1)+classification_matrix_shortening(2,2))/N;
p_e = ((1/(N*N))*((classification_matrix_shortening(1,1)+classification_matrix_shortening(1,2))*(classification_matrix_shortening(1,1)+classification_matrix_shortening(2,1))))+((1/(N*N))*((classification_matrix_shortening(2,1)+classification_matrix_shortening(2,2))*(classification_matrix_shortening(1,2)+classification_matrix_shortening(2,2))));
se_kappa_short = sqrt((p*(1-p))/(N*((1-p_e)*(1-p_e))));
upper_confidence_on_kappa_for_shortening = kappa_for_shortening+1.96*se_kappa_short
lower_confidence_on_kappa_for_shortening = kappa_for_shortening-1.96*se_kappa_short

%Accuracy
accuracy_for_prolongation = 100.*(classification_matrix_prolongation(1,1)+classification_matrix_prolongation(2,2))/(N)
upper_accuracy_for_prolongation= 100.*((N/(N+(1.96*1.96)))*(0.01*accuracy_for_prolongation+((1.96*1.96)/(2*N)) +(1.96*sqrt(((0.01*accuracy_for_prolongation*(1-0.01*accuracy_for_prolongation))/N)+((1.96*1.96)/(4*N*N))))))
lower_accuracy_for_prolongation = 100.*((N/(N+(1.96*1.96)))*(0.01*accuracy_for_prolongation+((1.96*1.96)/(2*N)) -(1.96*sqrt(((0.01*accuracy_for_prolongation*(1-0.01*accuracy_for_prolongation))/N)+((1.96*1.96)/(4*N*N))))))
accuracy_for_shortening = 100.*(classification_matrix_shortening(1,1)+classification_matrix_shortening(2,2))/(N)
upper_accuracy_for_shortening= 100.*((N/(N+(1.96*1.96)))*(0.01*accuracy_for_shortening+((1.96*1.96)/(2*N)) +(1.96*sqrt(((0.01*accuracy_for_shortening*(1-0.01*accuracy_for_shortening))/N)+((1.96*1.96)/(4*N*N))))))
lower_accuracy_for_shortening = 100.*((N/(N+(1.96*1.96)))*(0.01*accuracy_for_shortening+((1.96*1.96)/(2*N)) -(1.96*sqrt(((0.01*accuracy_for_shortening*(1-0.01*accuracy_for_shortening))/N)+((1.96*1.96)/(4*N*N))))) )
%Sensitivity
N_1 = classification_matrix_prolongation(1,1)  + classification_matrix_prolongation(1,2);
sensitivity_for_prolongation = 100.*(classification_matrix_prolongation(1,1)./(classification_matrix_prolongation(1,1) + classification_matrix_prolongation(1,2)))
upper_sensitivity_for_prolongation= 100.*((N_1/(N_1+(1.96*1.96)))*(0.01*sensitivity_for_prolongation+((1.96*1.96)/(2*N_1)) +(1.96*sqrt(((0.01*sensitivity_for_prolongation*(1-0.01*sensitivity_for_prolongation))/N_1)+((1.96*1.96)/(4*N_1*N_1))))))
lower_sensitivity_for_prolongation = 100.*((N_1/(N_1+(1.96*1.96)))*(0.01*sensitivity_for_prolongation+((1.96*1.96)/(2*N_1)) -(1.96*sqrt(((0.01*sensitivity_for_prolongation*(1-0.01*sensitivity_for_prolongation))/N_1)+((1.96*1.96)/(4*N_1*N_1))))))
N_1 = classification_matrix_shortening(1,1)  + classification_matrix_shortening(1,2);
sensitivity_for_shortening = 100.*(classification_matrix_shortening(1,1)./(classification_matrix_shortening(1,1) + classification_matrix_shortening(1,2)))
upper_sensitivity_for_shortening= 100.*((N_1/(N_1+(1.96*1.96)))*(0.01*sensitivity_for_shortening+((1.96*1.96)/(2*N_1)) +(1.96*sqrt(((0.01*sensitivity_for_shortening*(1-0.01*sensitivity_for_shortening))/N_1)+((1.96*1.96)/(4*N_1*N_1))))))
lower_sensitivity_for_shortening = 100.*((N_1/(N_1+(1.96*1.96)))*(0.01*sensitivity_for_shortening+((1.96*1.96)/(2*N_1)) -(1.96*sqrt(((0.01*sensitivity_for_shortening*(1-0.01*sensitivity_for_shortening))/N_1)+((1.96*1.96)/(4*N_1*N_1))))))

%Specificity
N_2 = classification_matrix_prolongation(2,1) + classification_matrix_prolongation(2,2);
specificity_for_prolongation = 100.*(classification_matrix_prolongation(2,2)./(classification_matrix_prolongation(2,1) + classification_matrix_prolongation(2,2)))
upper_specificity_for_prolongation= 100.*((N_2/(N_2+(1.96*1.96)))*(0.01*specificity_for_prolongation+((1.96*1.96)/(2*N_2)) +(1.96*sqrt(((0.01*specificity_for_prolongation*(1-0.01*specificity_for_prolongation))/N_2)+((1.96*1.96)/(4*N_2*N_2))))))
lower_specificity_for_prolongation = 100.*((N_2/(N_2+(1.96*1.96)))*(0.01*specificity_for_prolongation+((1.96*1.96)/(2*N_2)) -(1.96*sqrt(((0.01*specificity_for_prolongation*(1-0.01*specificity_for_prolongation))/N_2)+((1.96*1.96)/(4*N_2*N_2))))))
N_2 = classification_matrix_shortening(2,1) + classification_matrix_shortening(2,2);
specificity_for_shortening = 100.*(classification_matrix_shortening(2,2)./(classification_matrix_shortening(2,1) + classification_matrix_shortening(2,2)))
upper_specificity_for_shortening=100.*((N_2/(N_2+(1.96*1.96)))*(0.01*specificity_for_shortening+((1.96*1.96)/(2*N_2)) +(1.96*sqrt(((0.01*specificity_for_shortening*(1-0.01*specificity_for_shortening))/N_2)+((1.96*1.96)/(4*N_2*N_2))))))
lower_specificity_for_shortening = 100.*((N_2/(N_2+(1.96*1.96)))*(0.01*specificity_for_shortening+((1.96*1.96)/(2*N_2)) -(1.96*sqrt(((0.01*specificity_for_shortening*(1-0.01*specificity_for_shortening))/N_2)+((1.96*1.96)/(4*N_2*N_2))))))

% Positive Predictive Value
N_3 = classification_matrix_prolongation(1,1) + classification_matrix_prolongation(2,1);
ppv_for_prolongation = 100.*(classification_matrix_prolongation(1,1)./(classification_matrix_prolongation(1,1) + classification_matrix_prolongation(2,1)))
upper_ppv_for_prolongation= 100.*((N_3/(N_3+(1.96*1.96)))*(0.01*ppv_for_prolongation+((1.96*1.96)/(2*N_3)) +(1.96*sqrt(((0.01*ppv_for_prolongation*(1-0.01*ppv_for_prolongation))/N_3)+((1.96*1.96)/(4*N_3*N_3))))))
lower_ppv_for_prolongation = 100.*((N_3/(N_3+(1.96*1.96)))*(0.01*ppv_for_prolongation+((1.96*1.96)/(2*N_3)) -(1.96*sqrt(((0.01*ppv_for_prolongation*(1-0.01*ppv_for_prolongation))/N_3)+((1.96*1.96)/(4*N_3*N_3))))))

ppv_for_shortening = 100.*(classification_matrix_shortening(1,1)./(classification_matrix_shortening(1,1) + classification_matrix_shortening(2,1)))
upper_ppv_for_shortening= 100.*((N_3/(N_3+(1.96*1.96)))*(0.01*ppv_for_shortening+((1.96*1.96)/(2*N_3)) +(1.96*sqrt(((0.01*ppv_for_shortening*(1-0.01*ppv_for_shortening))/N_3)+((1.96*1.96)/(4*N_3*N_3))))))
lower_ppv_for_shortening = 100.*((N_3/(N_3+(1.96*1.96)))*(0.01*ppv_for_shortening+((1.96*1.96)/(2*N_3)) -(1.96*sqrt(((0.01*ppv_for_shortening*(1-0.01*ppv_for_shortening))/N_3)+((1.96*1.96)/(4*N_3*N_3))))))

% Negative Predictive Value
N_4 = classification_matrix_prolongation(1,2) + classification_matrix_prolongation(2,2);
npv_for_prolongation = 100.*(classification_matrix_prolongation(2,2)./(classification_matrix_prolongation(1,2) + classification_matrix_prolongation(2,2)))

upper_npv_for_prolongation= 100.*((N_4/(N_4+(1.96*1.96)))*(0.01*npv_for_prolongation+((1.96*1.96)/(2*N_4)) +(1.96*sqrt(((0.01*npv_for_prolongation*(1-0.01*npv_for_prolongation))/N_4)+((1.96*1.96)/(4*N_4*N_4))))))
lower_npv_for_prolongation = 100.*((N_4/(N_4+(1.96*1.96)))*(0.01*npv_for_prolongation+((1.96*1.96)/(2*N_4)) -(1.96*sqrt(((0.01*npv_for_prolongation*(1-0.01*npv_for_prolongation))/N_4)+((1.96*1.96)/(4*N_4*N_4))))))
N_4 = classification_matrix_shortening(1,2) + classification_matrix_shortening(2,2);
npv_for_shortening = 100.*(classification_matrix_shortening(2,2)./(classification_matrix_shortening(1,2) + classification_matrix_shortening(2,2)))
upper_npv_for_shortening= 100.*((N_4/(N_4+(1.96*1.96)))*(0.01*npv_for_shortening+((1.96*1.96)/(2*N_4)) +(1.96*sqrt(((0.01*npv_for_shortening*(1-0.01*npv_for_shortening))/N_4)+((1.96*1.96)/(4*N_4*N_4))))))
lower_npv_for_shortening = 100.*((N_4/(N_4+(1.96*1.96)))*(0.01*npv_for_shortening+((1.96*1.96)/(2*N_4)) -(1.96*sqrt(((0.01*npv_for_shortening*(1-0.01*npv_for_shortening))/N_4)+((1.96*1.96)/(4*N_4*N_4))))))
